Format etymological data of reptiles
Extracts and formats the etymological information associated with reptile species.
Source: R/accessory_functions.R
format_etymology.RdFormat etymological data of reptiles
Extracts and formats the etymological information associated with reptile species.
Arguments
- reptile_data
A data frame obtained using the
get_reptiledb_data()function.