Format bibliographic reference data of reptiles
Extracts and formats bibliographic references associated with reptile species.
Source: R/accessory_functions.R
format_references.RdFormat bibliographic reference data of reptiles
Extracts and formats bibliographic references associated with reptile species.
Arguments
- reptile_data
A data frame obtained using the
get_reptiledb_data()function.