Skip to contents

This function processes results from a ReptileDB database search to extract subspecies information. It identifies species that have subspecies and returns a tibble with the species name, subspecies name, and author information.

Usage

list_subspecies_reptiledbr(df)

Arguments

df

A dataframe or tibble result from using reptiledbr_exact, reptiledbr_partial or search_reptiledbr functions.

Value

A tibble with three columns:

species

The name of the species

subspecies_name

The full name of the subspecies

author

The author and year of the subspecies description

Examples

subspecies_names <- c("Lachesis muta",
  "Anilius scytale",
  "Anolis bahorucoensis")

search_reptiledbr(subspecies_names, use_fuzzy = FALSE) |>
  list_subspecies_reptiledbr()
#> # A tibble: 4 × 3
#>   species              subspecies_name                    author              
#>   <chr>                <chr>                              <chr>               
#> 1 Anilius scytale      Anilius scytale phelpsorum         Roze 1958           
#> 2 Anilius scytale      Anilius scytale scytale            Linnaeus 1758       
#> 3 Anolis bahorucoensis Anolis bahorucoensis bahorucoensis Noble & Hassler 1933
#> 4 Anolis bahorucoensis Anolis bahorucoensis southerlandi  Schwartz 1978